#include "cybsp.h"
#include "cyhal.h"

#include "waveform.h"

static cy_stc_scb_spi_context_t spiCtx;
static uint32_t buffer0[3] = {0x12, 0x34, 0x56};
static uint32_t buffer1[3] = {0xEE, 0xBB, 0xCC};
static uint32_t* buffers[2] = {buffer0, buffer1};

static uint16_t* chs[4] = {waveform_ch1, waveform_ch2, waveform_ch3, waveform_trig};

static cy_stc_dma_descriptor_t descriptorTransmission0;
static cy_stc_dma_descriptor_t descriptorTransmission1;

static int activeDescriptor = 0;
static int activeChannel = 0;
static int activeIndex = 0;

static int channelsCount = sizeof(chs) / sizeof(*chs);
static int dataCount = sizeof(waveform_ch1) / sizeof(*waveform_ch1);

void scb_1_interrupt_IRQHandler(void) {
    Cy_SCB_SPI_Interrupt(SCB1, &spiCtx);
}

void loadBuffer() {
	uint32_t* buffer = buffers[activeDescriptor];

	buffer[0] = activeChannel;
	if (activeChannel == channelsCount - 1) {
		buffer[0] |= 0x20;
	}

	uint16_t val = chs[activeChannel][activeIndex];
	buffer[1] = val >> 4;
	buffer[2] = val << 4;

	activeDescriptor = (activeDescriptor + 1) % 2;
	activeChannel = (activeChannel + 1) % channelsCount;
	if (activeChannel == 0) {
		activeIndex = (activeIndex + 1) % dataCount;
	}
}

void cpuss_interrupts_dw0_0_IRQHandler(void) {
    cy_en_dma_intr_cause_t status = Cy_DMA_Channel_GetStatus(DW0, 0);
    if (status != CY_DMA_INTR_CAUSE_COMPLETION) {
        __BKPT(0);
    }

	loadBuffer();

    Cy_DMA_Channel_ClearInterrupt(DW0, 0);
}

int main(void) {
    cy_rslt_t cyStatus;

    cyStatus = cybsp_init();
    CY_ASSERT(cyStatus == CY_RSLT_SUCCESS);

    __enable_irq();

    NVIC_ClearPendingIRQ(scb_1_interrupt_IRQn);
    NVIC_EnableIRQ(scb_1_interrupt_IRQn);

    cyStatus = Cy_SCB_SPI_Init(scb_1_HW, &scb_1_config, &spiCtx);
    CY_ASSERT(cyStatus == CY_RSLT_SUCCESS);
    Cy_SCB_SPI_SetActiveSlaveSelect(scb_1_HW, CY_SCB_SPI_SLAVE_SELECT0);
    Cy_SCB_SPI_Enable(scb_1_HW);

    cyStatus = Cy_TCPWM_Counter_Init(tcpwm_0_group_0_cnt_0_HW, tcpwm_0_group_0_cnt_0_NUM, &tcpwm_0_group_0_cnt_0_config);
    CY_ASSERT(cyStatus == CY_RSLT_SUCCESS);
    Cy_TCPWM_Counter_Enable(tcpwm_0_group_0_cnt_0_HW, tcpwm_0_group_0_cnt_0_NUM);
	Cy_TCPWM_Enable_Single(tcpwm_0_group_0_cnt_0_HW, tcpwm_0_group_0_cnt_0_NUM);
	Cy_TCPWM_TriggerStart_Single(tcpwm_0_group_0_cnt_0_HW, tcpwm_0_group_0_cnt_0_NUM);
	Cy_TCPWM_Counter_SetPeriod(tcpwm_0_group_0_cnt_0_HW, tcpwm_0_group_0_cnt_0_NUM, 500);
	Cy_TCPWM_Counter_SetCounter(tcpwm_0_group_0_cnt_0_HW, tcpwm_0_group_0_cnt_0_NUM, 0);

    cy_stc_dma_descriptor_config_t descriptorConfig;

    descriptorConfig.channelState = CY_DMA_CHANNEL_ENABLED;
    descriptorConfig.interruptType = CY_DMA_DESCR;
    descriptorConfig.triggerOutType = CY_DMA_DESCR;
    descriptorConfig.triggerInType = CY_DMA_DESCR;
    descriptorConfig.srcXincrement = 1;
    descriptorConfig.dstXincrement = 0;
    descriptorConfig.xCount = 3;
    descriptorConfig.srcYincrement = 0;
    descriptorConfig.dstYincrement = 0;
    descriptorConfig.yCount = 1;
    descriptorConfig.descriptorType = CY_DMA_2D_TRANSFER;
    descriptorConfig.dataSize = CY_DMA_WORD;
    descriptorConfig.dstAddress = (void *)&(SCB1->TX_FIFO_WR);
	descriptorConfig.retrigger = CY_DMA_RETRIG_IM;

    descriptorConfig.srcAddress = buffer0;
    descriptorConfig.nextDescriptor = &descriptorTransmission1;
    cyStatus = Cy_DMA_Descriptor_Init(&descriptorTransmission0, &descriptorConfig);
    CY_ASSERT(cyStatus == 0);
	
    descriptorConfig.srcAddress = buffer1;
    descriptorConfig.nextDescriptor = &descriptorTransmission0;
    cyStatus = Cy_DMA_Descriptor_Init(&descriptorTransmission1, &descriptorConfig);
    CY_ASSERT(cyStatus == 0);

    NVIC_SetPriority(cpuss_interrupts_dw0_0_IRQn, 3);
    NVIC_ClearPendingIRQ(cpuss_interrupts_dw0_0_IRQn);
    NVIC_EnableIRQ(cpuss_interrupts_dw0_0_IRQn);

	loadBuffer();
	loadBuffer();

    Cy_DMA_Channel_SetDescriptor(DW0, 0, &descriptorTransmission0);
    Cy_DMA_Channel_SetPriority(DW0, 0, 2);
    Cy_DMA_Channel_SetInterruptMask(DW0, 0, CY_DMA_INTR_MASK);
    Cy_DMA_Enable(DW0);
    Cy_DMA_Channel_Enable(DW0, 0);

    for (;;) {
    }
}
